@@ -10,12 +10,12 @@ pn.Column(
 production. Panel is very popular in *real* science, engineering and finance. It can be used successfully in
 any domain.
 
-[Panel sharing](https://github.com/awesome-panel/panel-sharing) is **the fastest way to develop, [convert](https://panel.holoviz.org/user_guide/Running_in_Webassembly.html) and share Panel data apps**.
+[Panel sharing](https://github.com/awesome-panel/panel-sharing) is **the fastest way to develop, [convert](https://panel.holoviz.org/user_guide/Running_in_Webassembly.html) and share Panel data apps**. Check out the [User Guide](https://github.com/awesome-panel/panel-sharing/blob/main/docs/user-guide.md) to learn more.
 
 Panel Sharing was made with Panel! Check out the code and **report issues
 [here](https://github.com/awesome-panel/panel-sharing)**.
 
-**Select an example app in the sidebar** to get started.
+**Select an example app in the sidebar** or from the [Gallery](https://awesome-panel.org/sharing_gallery) to get started.
 """
     ),
     pn.pane.Alert(
