@@ -5,12 +5,12 @@ from __future__ import annotations
 import base64
 import json
 import multiprocessing
+import os
 import pathlib
 import shutil
-import sys
 import tempfile
 import uuid
-from io import BytesIO, StringIO
+from io import BytesIO
 from pathlib import Path
 from typing import Dict, List
 
@@ -19,12 +19,18 @@ from azure.core.exceptions import ResourceNotFoundError
 from azure.storage.blob import BlobServiceClient, ContentSettings
 from azure.storage.blob._list_blobs_helper import BlobPrefix
 from panel import __version__
-from panel.io.convert import convert_app
 
 from panel_sharing import VERSION, config
+from panel_sharing.convert import _convert_project
+from panel_sharing.shared.azure.cdn import AzureCDN
 from panel_sharing.utils import Timer, set_directory
 
-ctx_forkserver = multiprocessing.get_context("forkserver")
+if os.name == "nt":
+    CTX_METHOD = "spawn"
+else:
+    CTX_METHOD = "forkserver"
+
+ctx_forkserver = multiprocessing.get_context(CTX_METHOD)
 ctx_forkserver.set_forkserver_preload(
     [
         # "base64",
@@ -43,87 +49,7 @@ ctx_forkserver.set_forkserver_preload(
 )
 
 EXAMPLES = Path(__file__).parent / "examples"
-
-ALERT_STYLE = """
-<style>
-.bk.alert {
-    padding: 0.75rem 1.25rem;
-    border: 1px solid transparent;
-    border-radius: 0.25rem;
-    margin-top: 15px;
-    margin-bottom: 15px;
-}
-.bk.alert a {
-    color: rgb(11, 46, 19); /* #002752; */
-    font-weight: 700;
-    text-decoration: rgb(11, 46, 19);
-    text-decoration-color: rgb(11, 46, 19);
-    text-decoration-line: none;
-    text-decoration-style: solid;
-    text-decoration-thickness: auto;
-  }
-.bk.alert a:hover {
-    color: rgb(11, 46, 19);
-    font-weight: 700;
-    text-decoration: underline;
-}
-.bk.alert-danger {
-    color: #721c24;
-    background-color: #f8d7da;
-    border-color: #f5c6cb;
-}
-.bk.alert-danger hr {
-    border-top-color: #f1b0b7;
-}
-</style>
-"""
-
-
-class ConversionError(Exception):
-    """Raised if the app cannot be converted"""
-
-
-def _convert_project(app: str = "source/app.py", dest_path: str = "build", requirements="auto"):
-    """Helper function"""
-    build_dir = Path(dest_path)
-    build_dir.mkdir(parents=True, exist_ok=True)
-
-    temp_out = StringIO()
-    sys.stdout = temp_out
-    convert_app(
-        app=Path(app), # type: ignore
-        dest_path=Path(dest_path), # type: ignore
-        requirements=requirements,
-        prerender=True
-    )
-
-    if not ((build_dir / "app.html").exists() and (build_dir / "app.js").exists()):
-        temp_out = StringIO()
-        sys.stdout = temp_out
-        convert_app(
-            app=Path(app), # type: ignore
-            dest_path=Path(dest_path), # type: ignore
-            requirements=requirements,
-            prerender=False
-        )  # type: ignore
-
-    out = temp_out.getvalue()
-    sys.stdout = sys.__stdout__
-    if (build_dir / "app.html").exists() and (build_dir / "app.js").exists():
-        return
-
-    if out.startswith("Failed to convert"):
-        out = """\n\nFailed to convert. Make sure you are 1) marking items .servable() and 2) only
-importing packages available on the server."""
-
-    app_html_path = Path(dest_path) / "app.html"
-    app_html_path.parent.mkdir(parents=True, exist_ok=True)
-    app_html_path.write_text(
-        f"""
-{ALERT_STYLE}<div class="bk alert alert-danger">{out}</div>
-"""
-    )
-    raise ConversionError(out)
+AZURE_CDN = AzureCDN()
 
 
 class Source(param.Parameterized):
@@ -156,9 +82,9 @@ class Source(param.Parameterized):
         """Reads the Source from the current working directory"""
         path = pathlib.Path()
         source = cls(name="new")
-        source.code = (path / "app.py").read_text()
-        source.readme = (path / "readme.md").read_text()
-        source.requirements = (path / "requirements.txt").read_text()
+        source.code = (path / "app.py").read_text(encoding="utf8")
+        source.readme = (path / "readme.md").read_text(encoding="utf8")
+        source.requirements = (path / "requirements.txt").read_text(encoding="utf8")
         return source
 
     def to_dict(self) -> Dict:
@@ -338,7 +264,12 @@ class Project(param.Parameterized):
 
     def to_base64(self):
         """Returns the project base64 encoded"""
-        value = json.dumps(self.to_dict(), separators=(",", ":"))
+        project_dict = self.to_dict()
+        source_dict = project_dict.get("source", {})
+        project_dict["source"] = {
+            key: value for key, value in source_dict.items() if key in ["code", "requirements"]
+        }
+        value = json.dumps(project_dict, separators=(",", ":"))
         result = base64.b64encode(value.encode(encoding="utf8")).decode(encoding="utf8")
         print("base64 len", len(result))
         return result
@@ -579,7 +510,7 @@ class AzureBlobStorage(Storage):
 
     @staticmethod
     def _is_build_file(file: Path):
-        return str(file).startswith("build/")
+        return str(file).startswith("build/") or str(file).startswith("build\\")
 
     def _get_container_name(self, file: Path):
         if self._is_build_file(file):
@@ -618,6 +549,7 @@ class AzureBlobStorage(Storage):
                             blob_client.upload_blob(
                                 data, overwrite=True, content_settings=content_settings
                             )
+                AZURE_CDN.purge(content_paths=[f"/{key}/*"])
 
     def __delitem__(self, key):
         raise NotImplementedError()
@@ -646,7 +578,7 @@ class AzureBlobStorage(Storage):
         file = Path(file)
         container_name = self._get_container_name(file)
         file_path = self._get_file_path(file)
-        if container_name == "$web":
+        if container_name.endswith("web"):
             return self.web_url + key + "/" + str(file_path)
         return self.blob_url + container_name + "/" + key + "/" + str(file_path)
 
